@@ -13,7 +13,7 @@ void reset_handle(HANDLE& handle)
 		CloseHandle(handle);
 		handle = INVALID_HANDLE_VALUE;
 	}
-};
+}
 
 bool uninherit(HANDLE& handle)
 {
@@ -124,7 +124,7 @@ public:
 		auto cmdline_buf = &cmdline[0];
 
 		DWORD const flags = CREATE_UNICODE_ENVIRONMENT | CREATE_DEFAULT_ERROR_MODE | CREATE_NO_WINDOW;
-		BOOL res = CreateProcess(cmd.c_str(), cmdline_buf, 0, 0, TRUE, flags, 0, 0, &si, &pi);
+		BOOL res = CreateProcess(cmd.c_str(), cmdline_buf, nullptr, nullptr, TRUE, flags, nullptr, nullptr, &si, &pi);
 		if (!res) {
 			return false;
 		}
@@ -156,7 +156,7 @@ public:
 	int read(char* buffer, unsigned int len)
 	{
 		DWORD read = 0;
-		BOOL res = ReadFile(out_.read_, buffer, len, &read, 0);
+		BOOL res = ReadFile(out_.read_, buffer, len, &read, nullptr);
 		if (!res) {
 #if FZ_WINDOWS
 			// ERROR_BROKEN_PIPE indicated EOF.
@@ -173,7 +173,7 @@ public:
 	{
 		while (len > 0) {
 			DWORD written = 0;
-			BOOL res = WriteFile(in_.write_, buffer, len, &written, 0);
+			BOOL res = WriteFile(in_.write_, buffer, len, &written, nullptr);
 			if (!res || written == 0) {
 				return false;
 			}
@@ -349,7 +349,7 @@ public:
 		for (auto const& a : argList) {
 			*(v++) = a.get();
 		}
-		*v = 0;
+		*v = nullptr;
 	}
 
 	bool spawn(native_string const& cmd, std::vector<native_string> const& args)
@@ -362,6 +362,10 @@ public:
 			return false;
 		}
 
+		std::vector<std::unique_ptr<char[]>> argList;
+		std::unique_ptr<char *[]> argV;
+		get_argv(cmd, args, argList, argV);
+
 		int pid = fork();
 		if (pid < 0) {
 			return false;
@@ -382,10 +386,6 @@ public:
 				_exit(-1);
 			}
 
-			std::vector<std::unique_ptr<char[]>> argList;
-			std::unique_ptr<char *[]> argV;
-			get_argv(cmd, args, argList, argV);
-
 			// Execute process
 			execv(cmd.c_str(), argV.get()); // noreturn on success
 
@@ -413,7 +413,7 @@ public:
 
 			int ret;
 			do {
-			} while ((ret = waitpid(pid_, 0, 0)) == -1 && errno == EINTR);
+			} while ((ret = waitpid(pid_, nullptr, 0)) == -1 && errno == EINTR);
 
 			(void)ret;
 
